@@ -1,13 +1,8 @@
 import os
 import sys
 import cv2
-__dir__ = os.path.dirname(__file__)
 
-# import paddle
-
-sys.path.append(os.path.join(__dir__, ''))
-
-from .PaddleOCR.paddleocr import PaddleOCR
+from PaddleOCR.paddleocr import PaddleOCR
 import numpy as np
 import unicodedata as ud
 
@@ -162,4 +157,6 @@ class OcrLicense:
                 if output["name"] != "" and output["address"] != "":
                     break
 
-        return output
\ No newline at end of file
+        return output
+
+OcrLicense()
\ No newline at end of file
